@@ -237,12 +237,11 @@ def extract_by_var(vars, state_codes,
             if not os.path.exists(export_tmp_fp):
                 result_df.to_parquet(export_tmp_fp, compression='gzip')
             else:
-                result_df.drop(['county','state'])
                 tmp_df = result_df.join(tmp_df, how='left', lsuffix='_delete')
                 if 'county_delete' in tmp_df:
-                    tmp_df.drop(['county_delete'], inplace=True)
+                    tmp_df.drop(columns=['county_delete'], inplace=True)
                 if 'state_delete' in tmp_df:
-                    tmp_df.drop(['state_delete'], inplace=True)    
+                    tmp_df.drop(columns=['state_delete'], inplace=True)    
                 print(tmp_df)
                 tmp_df.to_parquet(export_tmp_fp, compression='gzip')
 
